"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resourcetypeenum import ResourceTypeEnum
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class ResourceToPublishDtoTypedDict(TypedDict):
    resource_type: ResourceTypeEnum
    r"""Type of the layout"""
    resource_id: str
    r"""Unique identifier of the resource to publish"""


class ResourceToPublishDto(BaseModel):
    resource_type: Annotated[ResourceTypeEnum, pydantic.Field(alias="resourceType")]
    r"""Type of the layout"""

    resource_id: Annotated[str, pydantic.Field(alias="resourceId")]
    r"""Unique identifier of the resource to publish"""


try:
    ResourceToPublishDto.model_rebuild()
except NameError:
    pass
