"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class StepsOverridesTypedDict(TypedDict):
    providers: NotRequired[Dict[str, Dict[str, Any]]]
    r"""Passing the provider id and the provider specific configurations"""
    layout_id: NotRequired[Nullable[str]]
    r"""Override the or remove the layout for this specific step"""


class StepsOverrides(BaseModel):
    providers: Optional[Dict[str, Dict[str, Any]]] = None
    r"""Passing the provider id and the provider specific configurations"""

    layout_id: Annotated[OptionalNullable[str], pydantic.Field(alias="layoutId")] = (
        UNSET
    )
    r"""Override the or remove the layout for this specific step"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["providers", "layoutId"])
        nullable_fields = set(["layoutId"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    StepsOverrides.model_rebuild()
except NameError:
    pass
