"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class PublishSummaryDtoTypedDict(TypedDict):
    resources: float
    r"""Number of resources processed"""
    successful: float
    r"""Number of successful syncs"""
    failed: float
    r"""Number of failed syncs"""
    skipped: float
    r"""Number of skipped resources"""


class PublishSummaryDto(BaseModel):
    resources: float
    r"""Number of resources processed"""

    successful: float
    r"""Number of successful syncs"""

    failed: float
    r"""Number of failed syncs"""

    skipped: float
    r"""Number of skipped resources"""
