"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChannelCredentialsDtoTypedDict(TypedDict):
    webhook_url: NotRequired[str]
    r"""The URL for the webhook associated with the channel."""
    device_tokens: NotRequired[List[str]]
    r"""An array of device tokens for push notifications."""


class ChannelCredentialsDto(BaseModel):
    webhook_url: Annotated[Optional[str], pydantic.Field(alias="webhookUrl")] = None
    r"""The URL for the webhook associated with the channel."""

    device_tokens: Annotated[
        Optional[List[str]], pydantic.Field(alias="deviceTokens")
    ] = None
    r"""An array of device tokens for push notifications."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["webhookUrl", "deviceTokens"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ChannelCredentialsDto.model_rebuild()
except NameError:
    pass
