"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class DiffSummaryDtoTypedDict(TypedDict):
    added: float
    r"""Number of added resources (workflows and steps)"""
    modified: float
    r"""Number of modified resources (workflows and steps)"""
    deleted: float
    r"""Number of deleted resources (workflows and steps)"""
    unchanged: float
    r"""Number of unchanged resources (workflows and steps)"""


class DiffSummaryDto(BaseModel):
    added: float
    r"""Number of added resources (workflows and steps)"""

    modified: float
    r"""Number of modified resources (workflows and steps)"""

    deleted: float
    r"""Number of deleted resources (workflows and steps)"""

    unchanged: float
    r"""Number of unchanged resources (workflows and steps)"""
