"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .triggereventrequestdto import (
    TriggerEventRequestDto,
    TriggerEventRequestDtoTypedDict,
)
from .triggereventresponsedto import (
    TriggerEventResponseDto,
    TriggerEventResponseDtoTypedDict,
)
from novu_py.types import BaseModel, UNSET_SENTINEL
from novu_py.utils import FieldMetadata, HeaderMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EventsControllerTriggerRequestTypedDict(TypedDict):
    trigger_event_request_dto: TriggerEventRequestDtoTypedDict
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class EventsControllerTriggerRequest(BaseModel):
    trigger_event_request_dto: Annotated[
        TriggerEventRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["idempotency-key"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class EventsControllerTriggerResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: TriggerEventResponseDtoTypedDict


class EventsControllerTriggerResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: TriggerEventResponseDto
