"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .publishsummarydto import PublishSummaryDto, PublishSummaryDtoTypedDict
from .syncresultdto import SyncResultDto, SyncResultDtoTypedDict
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PublishEnvironmentResponseDtoTypedDict(TypedDict):
    results: List[SyncResultDtoTypedDict]
    r"""Sync results by resource type"""
    summary: PublishSummaryDtoTypedDict
    r"""Summary of the sync operation"""


class PublishEnvironmentResponseDto(BaseModel):
    results: List[SyncResultDto]
    r"""Sync results by resource type"""

    summary: PublishSummaryDto
    r"""Summary of the sync operation"""
