"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PatchPreferenceChannelsDtoTypedDict(TypedDict):
    email: NotRequired[bool]
    r"""Email channel preference"""
    sms: NotRequired[bool]
    r"""SMS channel preference"""
    in_app: NotRequired[bool]
    r"""In-app channel preference"""
    push: NotRequired[bool]
    r"""Push channel preference"""
    chat: NotRequired[bool]
    r"""Chat channel preference"""


class PatchPreferenceChannelsDto(BaseModel):
    email: Optional[bool] = None
    r"""Email channel preference"""

    sms: Optional[bool] = None
    r"""SMS channel preference"""

    in_app: Optional[bool] = None
    r"""In-app channel preference"""

    push: Optional[bool] = None
    r"""Push channel preference"""

    chat: Optional[bool] = None
    r"""Chat channel preference"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email", "sms", "in_app", "push", "chat"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
