"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emailblockstyles import EmailBlockStyles, EmailBlockStylesTypedDict
from .emailblocktypeenum import EmailBlockTypeEnum
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EmailBlockTypedDict(TypedDict):
    type: EmailBlockTypeEnum
    r"""Type of the email block"""
    content: str
    r"""Content of the email block"""
    url: NotRequired[str]
    r"""URL associated with the email block, if any"""
    styles: NotRequired[EmailBlockStylesTypedDict]
    r"""Styles applied to the email block"""


class EmailBlock(BaseModel):
    type: EmailBlockTypeEnum
    r"""Type of the email block"""

    content: str
    r"""Content of the email block"""

    url: Optional[str] = None
    r"""URL associated with the email block, if any"""

    styles: Optional[EmailBlockStyles] = None
    r"""Styles applied to the email block"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["url", "styles"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
