"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resourcetypeenum import ResourceTypeEnum
from .syncactionenum import SyncActionEnum
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class SyncedWorkflowDtoTypedDict(TypedDict):
    resource_type: ResourceTypeEnum
    r"""Type of the layout"""
    resource_id: str
    r"""Resource ID"""
    resource_name: str
    r"""Resource name"""
    action: SyncActionEnum
    r"""Sync action performed"""


class SyncedWorkflowDto(BaseModel):
    resource_type: Annotated[ResourceTypeEnum, pydantic.Field(alias="resourceType")]
    r"""Type of the layout"""

    resource_id: Annotated[str, pydantic.Field(alias="resourceId")]
    r"""Resource ID"""

    resource_name: Annotated[str, pydantic.Field(alias="resourceName")]
    r"""Resource name"""

    action: SyncActionEnum
    r"""Sync action performed"""


try:
    SyncedWorkflowDto.model_rebuild()
except NameError:
    pass
