"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .uischemagroupenum import UISchemaGroupEnum
from .uischemaproperty import UISchemaProperty, UISchemaPropertyTypedDict
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class UISchemaTypedDict(TypedDict):
    group: NotRequired[UISchemaGroupEnum]
    r"""Group of the UI Schema"""
    properties: NotRequired[Dict[str, UISchemaPropertyTypedDict]]
    r"""Properties of the UI Schema"""


class UISchema(BaseModel):
    group: Optional[UISchemaGroupEnum] = None
    r"""Group of the UI Schema"""

    properties: Optional[Dict[str, UISchemaProperty]] = None
    r"""Properties of the UI Schema"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["group", "properties"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
