"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .metadto import MetaDto, MetaDtoTypedDict
from .subscriptionerrordto import SubscriptionErrorDto, SubscriptionErrorDtoTypedDict
from .subscriptionresponsedto import (
    SubscriptionResponseDto,
    SubscriptionResponseDtoTypedDict,
)
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CreateSubscriptionsResponseDtoTypedDict(TypedDict):
    data: List[SubscriptionResponseDtoTypedDict]
    r"""The list of successfully created subscriptions"""
    meta: MetaDtoTypedDict
    r"""Metadata about the operation"""
    errors: NotRequired[List[SubscriptionErrorDtoTypedDict]]
    r"""The list of errors for failed subscription attempts"""


class CreateSubscriptionsResponseDto(BaseModel):
    data: List[SubscriptionResponseDto]
    r"""The list of successfully created subscriptions"""

    meta: MetaDto
    r"""Metadata about the operation"""

    errors: Optional[List[SubscriptionErrorDto]] = None
    r"""The list of errors for failed subscription attempts"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["errors"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
