"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .buttontypeenum import ButtonTypeEnum
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class MessageButtonTypedDict(TypedDict):
    type: ButtonTypeEnum
    r"""Type of button for the action result"""
    content: str
    r"""Content of the button"""
    result_content: NotRequired[str]
    r"""Content of the result when the button is clicked"""


class MessageButton(BaseModel):
    type: ButtonTypeEnum
    r"""Type of button for the action result"""

    content: str
    r"""Content of the button"""

    result_content: Annotated[Optional[str], pydantic.Field(alias="resultContent")] = (
        None
    )
    r"""Content of the result when the button is clicked"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["resultContent"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    MessageButton.model_rebuild()
except NameError:
    pass
