"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resourcetypeenum import ResourceTypeEnum
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FailedWorkflowDtoTypedDict(TypedDict):
    resource_type: ResourceTypeEnum
    r"""Type of the layout"""
    resource_id: str
    r"""Resource ID"""
    resource_name: str
    r"""Resource name"""
    error: str
    r"""Error message"""
    stack: NotRequired[str]
    r"""Error stack trace"""


class FailedWorkflowDto(BaseModel):
    resource_type: Annotated[ResourceTypeEnum, pydantic.Field(alias="resourceType")]
    r"""Type of the layout"""

    resource_id: Annotated[str, pydantic.Field(alias="resourceId")]
    r"""Resource ID"""

    resource_name: Annotated[str, pydantic.Field(alias="resourceName")]
    r"""Resource name"""

    error: str
    r"""Error message"""

    stack: Optional[str] = None
    r"""Error stack trace"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["stack"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    FailedWorkflowDto.model_rebuild()
except NameError:
    pass
