"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicSubscriberIdentifierDtoTypedDict(TypedDict):
    identifier: str
    r"""Unique identifier for this subscription"""
    subscriber_id: str
    r"""The subscriber ID"""
    name: NotRequired[str]
    r"""The name of the subscription"""


class TopicSubscriberIdentifierDto(BaseModel):
    identifier: str
    r"""Unique identifier for this subscription"""

    subscriber_id: Annotated[str, pydantic.Field(alias="subscriberId")]
    r"""The subscriber ID"""

    name: Optional[str] = None
    r"""The name of the subscription"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["name"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    TopicSubscriberIdentifierDto.model_rebuild()
except NameError:
    pass
