"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channelpreferencedto import ChannelPreferenceDto, ChannelPreferenceDtoTypedDict
from .workflowpreferencedto import WorkflowPreferenceDto, WorkflowPreferenceDtoTypedDict
from .workflowpreferencesdto import (
    WorkflowPreferencesDto,
    WorkflowPreferencesDtoTypedDict,
)
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict
from typing_extensions import NotRequired, TypedDict


WorkflowPreferencesResponseDtoAllTypedDict = WorkflowPreferenceDtoTypedDict
r"""A preference for the workflow. The values specified here will be used if no preference is specified for a channel."""


WorkflowPreferencesResponseDtoAll = WorkflowPreferenceDto
r"""A preference for the workflow. The values specified here will be used if no preference is specified for a channel."""


class WorkflowPreferencesResponseDtoUserTypedDict(TypedDict):
    r"""User-specific workflow preferences"""

    all: WorkflowPreferencesResponseDtoAllTypedDict
    r"""A preference for the workflow. The values specified here will be used if no preference is specified for a channel."""
    channels: Dict[str, ChannelPreferenceDtoTypedDict]
    r"""Preferences for different communication channels"""


class WorkflowPreferencesResponseDtoUser(BaseModel):
    r"""User-specific workflow preferences"""

    all: WorkflowPreferencesResponseDtoAll
    r"""A preference for the workflow. The values specified here will be used if no preference is specified for a channel."""

    channels: Dict[str, ChannelPreferenceDto]
    r"""Preferences for different communication channels"""


class WorkflowPreferencesResponseDtoTypedDict(TypedDict):
    default: WorkflowPreferencesDtoTypedDict
    r"""Default workflow preferences"""
    user: NotRequired[Nullable[WorkflowPreferencesResponseDtoUserTypedDict]]
    r"""User-specific workflow preferences"""


class WorkflowPreferencesResponseDto(BaseModel):
    default: WorkflowPreferencesDto
    r"""Default workflow preferences"""

    user: OptionalNullable[WorkflowPreferencesResponseDtoUser] = UNSET
    r"""User-specific workflow preferences"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["user"])
        nullable_fields = set(["user"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
