"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SyncActionEnum(str, Enum):
    r"""Sync action performed"""

    CREATED = "created"
    UPDATED = "updated"
    SKIPPED = "skipped"
    DELETED = "deleted"
