"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .scheduledto import ScheduleDto, ScheduleDtoTypedDict
from .subscriberpreferencechannels import (
    SubscriberPreferenceChannels,
    SubscriberPreferenceChannelsTypedDict,
)
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SubscriberGlobalPreferenceDtoTypedDict(TypedDict):
    enabled: bool
    r"""Whether notifications are enabled globally"""
    channels: SubscriberPreferenceChannelsTypedDict
    r"""Channel-specific preference settings"""
    schedule: NotRequired[ScheduleDtoTypedDict]
    r"""Subscriber schedule"""


class SubscriberGlobalPreferenceDto(BaseModel):
    enabled: bool
    r"""Whether notifications are enabled globally"""

    channels: SubscriberPreferenceChannels
    r"""Channel-specific preference settings"""

    schedule: Optional[ScheduleDto] = None
    r"""Subscriber schedule"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["schedule"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
