"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bridgeconfigurationdto import (
    BridgeConfigurationDto,
    BridgeConfigurationDtoTypedDict,
)
from .inboundparsedomaindto import InBoundParseDomainDto, InBoundParseDomainDtoTypedDict
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateEnvironmentRequestDtoTypedDict(TypedDict):
    name: NotRequired[str]
    identifier: NotRequired[str]
    parent_id: NotRequired[str]
    color: NotRequired[str]
    dns: NotRequired[InBoundParseDomainDtoTypedDict]
    bridge: NotRequired[BridgeConfigurationDtoTypedDict]


class UpdateEnvironmentRequestDto(BaseModel):
    name: Optional[str] = None

    identifier: Optional[str] = None

    parent_id: Annotated[Optional[str], pydantic.Field(alias="parentId")] = None

    color: Optional[str] = None

    dns: Optional[InBoundParseDomainDto] = None

    bridge: Optional[BridgeConfigurationDto] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["name", "identifier", "parentId", "color", "dns", "bridge"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    UpdateEnvironmentRequestDto.model_rebuild()
except NameError:
    pass
