"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


FiveTypedDict = TypeAliasType("FiveTypedDict", Union[str, float, bool, Dict[str, Any]])


Five = TypeAliasType("Five", Union[str, float, bool, Dict[str, Any]])


class FourTypedDict(TypedDict):
    pass


class Four(BaseModel):
    pass


ValueTypedDict = TypeAliasType(
    "ValueTypedDict",
    Union[FourTypedDict, str, float, bool, List[Nullable[FiveTypedDict]]],
)
r"""Value that failed validation"""


Value = TypeAliasType("Value", Union[Four, str, float, bool, List[Nullable[Five]]])
r"""Value that failed validation"""


class ConstraintValidationTypedDict(TypedDict):
    messages: List[str]
    r"""List of validation error messages"""
    value: NotRequired[Nullable[ValueTypedDict]]
    r"""Value that failed validation"""


class ConstraintValidation(BaseModel):
    messages: List[str]
    r"""List of validation error messages"""

    value: OptionalNullable[Value] = UNSET
    r"""Value that failed validation"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["value"])
        nullable_fields = set(["value"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
