"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GroupPreferenceFilterDetailsDtoTypedDict(TypedDict):
    workflow_ids: NotRequired[List[str]]
    r"""List of workflow identifiers"""
    tags: NotRequired[List[str]]
    r"""List of tags"""


class GroupPreferenceFilterDetailsDto(BaseModel):
    workflow_ids: Annotated[
        Optional[List[str]], pydantic.Field(alias="workflowIds")
    ] = None
    r"""List of workflow identifiers"""

    tags: Optional[List[str]] = None
    r"""List of tags"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["workflowIds", "tags"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    GroupPreferenceFilterDetailsDto.model_rebuild()
except NameError:
    pass
