"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class APIKeyDtoTypedDict(TypedDict):
    key: str
    r"""API key"""
    user_id: str
    r"""User ID associated with the API key"""
    hash: NotRequired[str]
    r"""Hashed representation of the API key"""


class APIKeyDto(BaseModel):
    key: str
    r"""API key"""

    user_id: Annotated[str, pydantic.Field(alias="_userId")]
    r"""User ID associated with the API key"""

    hash: Optional[str] = None
    r"""Hashed representation of the API key"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["hash"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    APIKeyDto.model_rebuild()
except NameError:
    pass
