"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stepissuesdto import StepIssuesDto, StepIssuesDtoTypedDict
from .steptypeenum import StepTypeEnum
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class StepListResponseDtoTypedDict(TypedDict):
    slug: str
    r"""Slug of the step"""
    type: StepTypeEnum
    r"""Type of the step"""
    issues: NotRequired[StepIssuesDtoTypedDict]
    r"""Issues associated with the step"""


class StepListResponseDto(BaseModel):
    slug: str
    r"""Slug of the step"""

    type: StepTypeEnum
    r"""Type of the step"""

    issues: Optional[StepIssuesDto] = None
    r"""Issues associated with the step"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["issues"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
