"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DependencyReasonEnum(str, Enum):
    r"""Reason for the dependency"""

    LAYOUT_REQUIRED_FOR_WORKFLOW = "LAYOUT_REQUIRED_FOR_WORKFLOW"
    LAYOUT_EXISTS_IN_TARGET = "LAYOUT_EXISTS_IN_TARGET"
