"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class EnvironmentDiffSummaryDtoTypedDict(TypedDict):
    total_entities: float
    r"""Total number of entities compared"""
    total_changes: float
    r"""Total number of changes detected"""
    has_changes: bool
    r"""Whether any changes were detected"""


class EnvironmentDiffSummaryDto(BaseModel):
    total_entities: Annotated[float, pydantic.Field(alias="totalEntities")]
    r"""Total number of entities compared"""

    total_changes: Annotated[float, pydantic.Field(alias="totalChanges")]
    r"""Total number of changes detected"""

    has_changes: Annotated[bool, pydantic.Field(alias="hasChanges")]
    r"""Whether any changes were detected"""


try:
    EnvironmentDiffSummaryDto.model_rebuild()
except NameError:
    pass
