"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class NotificationGroupTypedDict(TypedDict):
    name: str
    environment_id: str
    organization_id: str
    id: NotRequired[str]
    parent_id: NotRequired[str]


class NotificationGroup(BaseModel):
    name: str

    environment_id: Annotated[str, pydantic.Field(alias="_environmentId")]

    organization_id: Annotated[str, pydantic.Field(alias="_organizationId")]

    id: Annotated[Optional[str], pydantic.Field(alias="_id")] = None

    parent_id: Annotated[Optional[str], pydantic.Field(alias="_parentId")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["_id", "_parentId"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    NotificationGroup.model_rebuild()
except NameError:
    pass
