"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .triggerrecipientstypeenum import TriggerRecipientsTypeEnum
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicPayloadDtoTypedDict(TypedDict):
    topic_key: str
    type: TriggerRecipientsTypeEnum
    exclude: NotRequired[List[str]]
    r"""Optional array of subscriber IDs to exclude from the topic trigger"""


class TopicPayloadDto(BaseModel):
    topic_key: Annotated[str, pydantic.Field(alias="topicKey")]

    type: TriggerRecipientsTypeEnum

    exclude: Optional[List[str]] = None
    r"""Optional array of subscriber IDs to exclude from the topic trigger"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["exclude"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    TopicPayloadDto.model_rebuild()
except NameError:
    pass
