"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "novu-py"
__version__: str = "3.14.1"
__openapi_doc_version__: str = "3.14.0"
__gen_version__: str = "2.846.1"
__user_agent__: str = "speakeasy-sdk/python 3.14.1 2.846.1 3.14.0 novu-py"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
