"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MarkMessageActionAsSeenDtoStatus(str, Enum):
    r"""Message action status"""

    PENDING = "pending"
    DONE = "done"


class MarkMessageActionAsSeenDtoPayloadTypedDict(TypedDict):
    r"""Message action payload"""


class MarkMessageActionAsSeenDtoPayload(BaseModel):
    r"""Message action payload"""


class MarkMessageActionAsSeenDtoTypedDict(TypedDict):
    status: MarkMessageActionAsSeenDtoStatus
    r"""Message action status"""
    payload: NotRequired[MarkMessageActionAsSeenDtoPayloadTypedDict]
    r"""Message action payload"""


class MarkMessageActionAsSeenDto(BaseModel):
    status: MarkMessageActionAsSeenDtoStatus
    r"""Message action status"""

    payload: Optional[MarkMessageActionAsSeenDtoPayload] = None
    r"""Message action payload"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["payload"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
