"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class CreateContextRequestDtoTypedDict(TypedDict):
    type: str
    r"""Context type (e.g., tenant, app, workspace). Must be lowercase alphanumeric with optional separators."""
    id: str
    r"""Unique identifier for this context. Must be lowercase alphanumeric with optional separators."""
    data: NotRequired[Dict[str, Any]]
    r"""Optional custom data to associate with this context."""


class CreateContextRequestDto(BaseModel):
    type: str
    r"""Context type (e.g., tenant, app, workspace). Must be lowercase alphanumeric with optional separators."""

    id: str
    r"""Unique identifier for this context. Must be lowercase alphanumeric with optional separators."""

    data: Optional[Dict[str, Any]] = None
    r"""Optional custom data to associate with this context."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["data"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
