"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicResponseDtoTypedDict(TypedDict):
    id: str
    r"""The identifier of the topic"""
    key: str
    r"""The unique key of the topic"""
    name: NotRequired[str]
    r"""The name of the topic"""
    created_at: NotRequired[str]
    r"""The date the topic was created"""
    updated_at: NotRequired[str]
    r"""The date the topic was last updated"""


class TopicResponseDto(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""The identifier of the topic"""

    key: str
    r"""The unique key of the topic"""

    name: Optional[str] = None
    r"""The name of the topic"""

    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None
    r"""The date the topic was created"""

    updated_at: Annotated[Optional[str], pydantic.Field(alias="updatedAt")] = None
    r"""The date the topic was last updated"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["name", "createdAt", "updatedAt"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    TopicResponseDto.model_rebuild()
except NameError:
    pass
