"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .actortypeenum import ActorTypeEnum
from novu_py.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class ActorFeedItemDtoTypedDict(TypedDict):
    data: Nullable[str]
    r"""The data associated with the actor, can be null if not applicable."""
    type: ActorTypeEnum
    r"""The type of the actor, indicating the role in the notification process."""


class ActorFeedItemDto(BaseModel):
    data: Nullable[str]
    r"""The data associated with the actor, can be null if not applicable."""

    type: ActorTypeEnum
    r"""The type of the actor, indicating the role in the notification process."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
