"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .uicomponentenum import UIComponentEnum
from novu_py import models
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import field_serializer, model_serializer
from typing import Any, Dict, List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


Placeholder5TypedDict = TypeAliasType(
    "Placeholder5TypedDict", Union[str, float, bool, Dict[str, Any]]
)


Placeholder5 = TypeAliasType("Placeholder5", Union[str, float, bool, Dict[str, Any]])


PlaceholderTypedDict = TypeAliasType(
    "PlaceholderTypedDict",
    Union[str, float, bool, Dict[str, Any], List[Placeholder5TypedDict]],
)
r"""Placeholder for the UI Schema Property"""


Placeholder = TypeAliasType(
    "Placeholder", Union[str, float, bool, Dict[str, Any], List[Placeholder5]]
)
r"""Placeholder for the UI Schema Property"""


class UISchemaPropertyTypedDict(TypedDict):
    component: UIComponentEnum
    r"""Component type for the UI Schema Property"""
    placeholder: NotRequired[Nullable[PlaceholderTypedDict]]
    r"""Placeholder for the UI Schema Property"""
    properties: NotRequired[Dict[str, UISchemaPropertyTypedDict]]
    r"""Properties of the UI Schema"""


class UISchemaProperty(BaseModel):
    component: UIComponentEnum
    r"""Component type for the UI Schema Property"""

    placeholder: OptionalNullable[Placeholder] = UNSET
    r"""Placeholder for the UI Schema Property"""

    properties: Optional[Dict[str, UISchemaProperty]] = None
    r"""Properties of the UI Schema"""

    @field_serializer("component")
    def serialize_component(self, value):
        if isinstance(value, str):
            try:
                return models.UIComponentEnum(value)
            except ValueError:
                return value
        return value

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["placeholder", "properties"])
        nullable_fields = set(["placeholder"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
